@@ -15,10 +15,18 @@ class PrivacyFormMixin(object):
             if field_name == 'for_instance':
                 field_name = ''
             ctype = ContentType.objects.get_for_model(self.instance)
-            privacy_setting = PrivacySetting.objects.get(
-                content_type=ctype, object_id=self.instance.pk,
-                field_name=field_name)
-            privacy_setting.level = PrivacyLevel.objects.get(
-                clearance_level=self.data[key])
-            privacy_setting.save()
+            kwargs = {
+                'content_type': ctype,
+                'object_id': self.instance.pk,
+                'field_name': field_name,
+            }
+            level = PrivacyLevel.objects.get(clearance_level=self.data[key])
+            try:
+                privacy_setting = PrivacySetting.objects.get(**kwargs)
+            except PrivacySetting.DoesNotExist:
+                kwargs.update({'level': level})
+                privacy_setting = PrivacySetting.objects.create(**kwargs)
+            else:
+                privacy_setting.level = level
+                privacy_setting.save()
         return instance
